#!/bin/sh

# Copyright (C) 2019-2023 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# Hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with hurd-cross.  If not, see <http://www.gnu.org/licenses/>.

. ./common-funcs.sh
. ./environment-variables.sh
. ./package-versions.sh

echo ""
echo "File: bootstrap-patch.sh"

print_info "***********************************"
print_info "Patching source files for bootstrap"
print_info "***********************************"

patch_gnumach () {
   if [ -d "$GNUMACH_SRC" ]; then
      return 0
   fi
   cd $GNUMACH_SRC
   #FIXED: Applied in compile-funcs.sh
   #apply_patch $SCRIPT_DIR/patches/gnumach/add-error-prints.diff 1
   #unapply_patch $SCRIPT_DIR/patches/gnumach/debug_all_traps_with_kdb.diff 1
   cd ..
}

patch_hurd() {
   if [ -d "$HURD_SRC" ]; then
      return 0
   fi
   cd $HURD_SRC
# FIXED: Applied in bootstrap-funcs.sh
   #apply_patch $SCRIPT_DIR/patches/hurd/configure.ac.diff
   #unapply_patch $SCRIPT_DIR/patches/hurd/configure.ac.diff
   cd ..
}

patch_gcc () {
    cd $GCC_SRC
#FIXED: Needed here in bootstrap-patch.sh, remove from compile-patch.sh
#Needed to get weak references to pthread functions in libstdc++.so.6.0.30
    apply_patch $SCRIPT_DIR/patches/gcc/libstdc++-hurd.diff 1
# FIXED: Applied in compile-patch.sh    
   #apply_patch $SCRIPT_DIR/patches/gcc/specs.patch 1
   #apply_patch $SCRIPT_DIR/patches/gcc/startfile_prefix.patch 1
# FIXED: Applied in bootstrap-funcs.sh
#   apply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
#   unapply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
   cd .. 
}

patch_glibc () {
   cd $GLIBC_SRC
   apply_patch $SCRIPT_DIR/patches/glibc/git-net-route.h.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/git-ip_mreqn.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/tg-mach-hurd-link.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/git-mach-headers-freestanding.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/git-bootstrap-enable_secure.diff 1
   apply_patch $SCRIPT_DIR/patches/glibc/local-no-bootstrap-fs-access.2.diff 1
   #NEEDED in compile-patch.sh for more packages, which???
   #   apply_patch $SCRIPT_DIR/patches/glibc/unsubmitted-clock_t_centiseconds.diff
   #NO: apply_patch $SCRIPT_DIR/patches/glibc/tg-bootstrap.diff 1
   cd ..
}

GNUMACH_PATCH="$GNUMACH_SRC".patch
HURD_PATCH="$HURD_SRC".patch
GCC_PATCH="$GCC_SRC".patch
GLIBC_PATCH="$GLIBC_SRC".patch

cd $SRC

if [ ! -f $STAMPS_BOOTSTRAP/$GNUMACH_PATCH ]; then
    print_info "Patching gnumach"
    patch_gnumach
    touch $STAMPS_BOOTSTRAP/$GNUMACH_PATCH
fi
#exit
if [ ! -f $STAMPS_BOOTSTRAP/$HURD_PATCH ]; then
    print_info "Patching Hurd"
    patch_hurd
    touch $STAMPS_BOOTSTRAP/$HURD_PATCH
fi
#exit
if [ ! -f $STAMPS_BOOTSTRAP/$GCC_PATCH ]; then
    print_info "Patching gcc"
    patch_gcc
    touch $STAMPS_BOOTSTRAP/$GCC_PATCH
fi
#exit
if [ ! -f $STAMPS_BOOTSTRAP/$GLIBC_PATCH ]; then
    print_info "Patching glibc"
    patch_glibc
    touch $STAMPS_BOOTSTRAP/$GLIBC_PATCH
fi

print_info "************************************"
print_info "Patching bootstrap sources completed"
print_info "************************************"

exit 0
