#!/bin/sh

# Copyright (C) 2019-2023 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# Hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with hurd-cross.  If not, see <http://www.gnu.org/licenses/>.

. ./common-funcs.sh
. ./environment-variables.sh
. ./package-versions.sh

echo ""
echo "File: compile-patch.sh"

print_info "*********************************"
print_info "Patching source files for compile"
print_info "*********************************"

patch_gnumach () {
   cd $GNUMACH_SRC
   apply_patch $SCRIPT_DIR/patches/gnumach/add-error-prints.diff 1
   apply_patch $SCRIPT_DIR/patches/gnumach/debug_all_traps_with_kdb.diff 1
   cd ..
}

patch_pkg-config () {
   cd $PKG_CONFIG_SRC
   apply_patch $SCRIPT_DIR/patches/pkg-config/glib-gettext.m4.diff 1
   cd ..
}

patch_linux-pam () {
    cd $PAM_SRC
    apply_patch $SCRIPT_DIR/patches/Linux-PAM/fix-autoreconf.patch 1
    apply_patch $SCRIPT_DIR/patches/Linux-PAM/hurd_no_setfsuid.diff 1
    apply_patch $SCRIPT_DIR/patches/Linux-PAM/modules_pam_limits_pam_limits.c.diff 1
    cd ..
}

#NOTE: Used in bootstrap-funcs.sh:install_hurd_headers()
#apply_patch $SCRIPT_DIR/patches/hurd/configure.ac.diff 1
#unapply_patch $SCRIPT_DIR/patches/hurd/configure.ac.diff 1
patch_hurd () {
   cd $HURD_SRC
#Wrong!!   apply_patch $SCRIPT_DIR/patches/hurd/add-libs.diff 1
#Upstreamed   apply_patch $SCRIPT_DIR/patches/hurd/fix-warnings.diff 1
   apply_patch $SCRIPT_DIR/patches/hurd/pfinet_Makefile.diff 1
   cd ..
}

patch_shadow () {
   cd $SHADOW_SRC
   apply_patch $SCRIPT_DIR/patches/shadow/src_Makefile.am.diff 1
   cd ..
}

patch_gcc () {
   cd $GCC_SRC
   #OBSOLETE apply_patch $SCRIPT_DIR/patches/gcc/gcc-Makefile.in.diff 1
   #OBSOLETE?? apply_patch $SCRIPT_DIR/patches/gcc/mkfixinc.sh.diff 1
   apply_patch $SCRIPT_DIR/patches/gcc/specs.patch 1
   apply_patch $SCRIPT_DIR/patches/gcc/startfile_prefix.patch 1
   #FIXME: fuzz 1
   #Used in bootstrap-funcs.sh
   #apply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
   #unapply_patch $SCRIPT_DIR/patches/gcc/fixinc_glimits.h.diff 1
# This patch is needed in bootstrap-patch.sh
   #apply_patch $SCRIPT_DIR/patches/gcc/libstdc++-hurd.diff 1
   cd .. 
}

patch_less () {
   cd $LESS_SRC
   apply_patch $SCRIPT_DIR/patches/less/less-608_filename.c.diff 1
   cd ..
}

#FIXED: Add stamps
GNUMACH_PATCH="$GNUMACH_SRC".patch
PKG_CONFIG_PATCH="$PKG_CONFIG_SRC".patch
PAM_PATCH="$PAM_SRC".patch
HURD_PATCH="$HURD_SRC".patch
SHADOW_PATCH="$SHADOW_SRC".patch
GCC_PATCH="$GCC_SRC".patch
LESS_PATCH="$LESS_SRC".patch

cd $SRC

if [ ! -f $STAMPS_COMPILE/$GNUMACH_PATCH ]; then
    print_info "Patching gnumach"
    patch_gnumach
    touch $STAMPS_COMPILE/$GNUMACH_PATCH
fi
#exit
if [ ! -f $STAMPS_COMPILE/$PKG_CONFIG_PATCH ]; then
    print_info "Patching pkg_config"
    patch_pkg-config
    touch $STAMPS_COMPILE/$PKG_CONFIG_PATCH
fi
#exit
if [ ! -f $STAMPS_COMPILE/$PAM_PATCH ]; then
   print_info "Patching Linux-PAM"
   patch_linux-pam
   touch $STAMPS_COMPILE/$PAM_PATCH
fi
#exit
if [ ! -f $STAMPS_COMPILE/$HURD_PATCH ]; then
    print_info "Patching hurd"
    patch_hurd
    touch $STAMPS_COMPILE/$HURD_PATCH
fi
#exit
if [ ! -f $STAMPS_COMPILE/$SHADOW_PATCH ]; then
    print_info "Patching shadow"
    patch_shadow
    touch $STAMPS_COMPILE/$SHADOW_PATCH
fi
#exit
if [ ! -f $STAMPS_COMPILE/$GCC_PATCH ]; then
    print_info "Patching gcc"
    patch_gcc
    touch $STAMPS_COMPILE/$GCC_PATCH
fi
#exit
if [ ! -f $STAMPS_COMPILE/$LESS_PATCH ]; then
    print_info "Patching less"
    patch_less
    touch $STAMPS_COMPILE/$LESS_PATCH
fi
#exit

print_info "**********************************"
print_info "Patching compile sources completed"
print_info "**********************************"

exit 0
