#!/bin/bash

# Copyright (C) 2019-2023 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# Hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with hurd-cross.  If not, see <http://www.gnu.org/licenses/>.

. ./environment-variables.sh

echo ""
echo "File: create-directories.sh"

print_info "NOTE: Do once only!!"
print_info ""

if [ ! -d $SYSTEM ]; then
    print_info "Creating SYSTEM = $SYSTEM"
    mkdir -p "$SYSTEM"
fi
if [ ! -d $SYSTEM/src ]; then
    print_info "Creating SRC = \$SYSTEM/src"
    mkdir -p $SRC
fi
    print_info ""
if [ ! -d $SYSTEM/stamps ]; then
    print_info "Creating STAMPS = $STAMPS"
    mkdir -p $STAMPS
fi
if [ ! -d $STAMPS/download ]; then
    print_info "Creating STAMPS_DOWNLOAD = \$STAMPS/download"
    mkdir $STAMPS_DOWNLOAD
fi
if [ ! -d $STAMPS/bootstrap ]; then
    print_info "Creating STAMPS_BOOTSTRAP = \$STAMPS/bootstrap"
    mkdir -p $STAMPS_BOOTSTRAP
fi
if [ ! -d $STAMPS/compile ]; then
    print_info "Creating STAMPS_COMPILE = \$STAMPS/compile"
    mkdir -p $STAMPS_COMPILE
fi
    print_info ""
if [ ! -d $LOGS ]; then
    print_info "Creating LOGS = $LOGS"
    mkdir -p $LOGS
fi
if [ ! -d $LOGS/download ]; then
    print_info "Creating LOGS_DOWNLOAD = \$LOGS/download"
    mkdir -p $LOGS_DOWNLOAD
fi
if [ ! -d $LOGS/bootstrap ]; then
    print_info "Creating LOGS_BOOTSTRAP = \$LOGS/bootstrap"
    mkdir -p $LOGS_BOOTSTRAP
fi
if [ ! -d $LOGS/compile ]; then
    print_info "Creating LOGS_COMPILE = \$LOGS/compile"
    mkdir -p $LOGS_COMPILE
fi

#TARGET=i686-pc-gnu
#CROSS_ROOT=/cross-tools
if [ ! -d $CROSS_ROOT ]; then
    print_info "Creating  CROSS_ROOT=$CROSS_ROOT"
    su -c "mkdir -p $CROSS_ROOT; chown $USER:$USER $CROSS_ROOT"
    mkdir -p $CROSS_ROOT/{include,lib,libexec,bin,sbin,etc,share,var}
    mkdir -p $CROSS_ROOT/$TARGET
    # Note: This link is needed for gcc-12/c++ to build.
    print_info "Linking $CROSS_ROOT/include to $CROSS_ROOT/$TARGET"
    ln -s $CROSS_ROOT/include $CROSS_ROOT/$TARGET
    print_info "Linking $CROSS_ROOT/lib to $CROSS_ROOT/$TARGET"
    ln -s $CROSS_ROOT/lib $CROSS_ROOT/$TARGET
    # print_info "Linking $CROSS_ROOT/bin to $CROSS_ROOT/$TARGET"
    # ln -s $CROSS_ROOT/bin $CROSS_ROOT/$TARGET
fi

#TARGET_ROOT=/tools
if [ ! -d $TARGET_ROOT ]; then
    print_info "Creating TARGET_ROOT = $TARGET_ROOT"
    su -c "mkdir -p $TARGET_ROOT; chown $USER:$USER $TARGET_ROOT"
    mkdir -p $TARGET_ROOT/{include,lib,libexec,bin,sbin,etc,share,var}
    mkdir -p $TARGET_ROOT/$TARGET
    print_info "Linking $TARGET_ROOT/include to $TARGET_ROOT/$TARGET"
    # Note: This link is needed for gcc-12/c++ to build.
    ln -s $TARGET_ROOT/include $TARGET_ROOT/$TARGET
    print_info "Linking $TARGET_ROOT/lib to $TARGET_ROOT/$TARGET"
    ln -s $TARGET_ROOT/lib $TARGET_ROOT/$TARGET
    # print_info "Linking $TARGET_ROOT/bin to $TARGET_ROOT/$TARGET"
    # ln -s $TARGET_ROOT/bin $TARGET_ROOT/$TARGET
fi
