#!/bin/sh

# Copyright (C) 2019-2023 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# Hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with hurd-cross.  If not, see <http://www.gnu.org/licenses/>.

. ./download-funcs.sh

echo ""
echo "File: download-bootstrap.sh"

print_info "***************************************************"
print_info "Downloading and patching source files for bootstrap"
print_info "***************************************************"

download_binutils () {
   download $BINUTILS_PKG $BINUTILS_URL
   if [ -d "$BINUTILS_SRC" ]; then
      return 0
   fi
   unpack jxf $BINUTILS_PKG $BINUTILS_SRC
 }

# git clone
download_gnumach () {
   if [ -d "$GNUMACH_SRC" ]; then
      return 0
   fi
   git clone https://git.savannah.gnu.org/git/hurd/gnumach.git
   mv "$GNUMACH" "$GNUMACH_SRC"
}

# git clone
download_mig () {
   if [ -d "$MIG_SRC" ]; then
      return 0
   fi
   git clone https://git.savannah.gnu.org/git/hurd/mig.git
   mv "$MIG" "$MIG_SRC"

}

#FIXME: lwip requires cmake!!
# git clone
download_lwip () {
   if [ -d "$LWIP_SRC" ]; then
      return 0
   fi
   git clone https://git.savannah.nongnu.org/git/lwip.git
   mv "$LWIP" "$LWIP_SRC"
}

# git clone
download_hurd () {
   if [ -d "$HURD_SRC" ]; then
      return 0
   fi
   git clone git://git.savannah.gnu.org/hurd/hurd.git
   mv "$HURD" "$HURD_SRC"
}

download_gcc () {
   download $GCC_PKG $GCC_URL
   if [ -d "$GCC_SRC" ]; then
      return 0
   fi
   unpack zxf $GCC_PKG $GCC_SRC
}

download_glibc () {
   download $GLIBC_PKG $GLIBC_URL
   if [ -d "$GLIBC_SRC" ]; then
      return 0
   fi
   unpack zxf $GLIBC_PKG $GLIBC_SRC
}

cd $SRC

if [ ! -f $STAMPS_DOWNLOAD/$BINUTILS_SRC ]; then
    print_info "Downloading binutils"
    download_binutils
    touch $STAMPS_DOWNLOAD/$BINUTILS_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$GNUMACH_SRC ]; then
    print_info "git clone gnumach"
    download_gnumach
    touch $STAMPS_DOWNLOAD/$GNUMACH_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$MIG_SRC ]; then
    print_info "git clone mig"
    download_mig
    touch $STAMPS_DOWNLOAD/$MIG_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$HURD_SRC ]; then
    print_info "git clone hurd"
    download_hurd
    touch $STAMPS_DOWNLOAD/$HURD_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$GCC_SRC ]; then
    print_info "Downloading gcc"
    download_gcc
    touch $STAMPS_DOWNLOAD/$GCC_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$GLIBC_SRC ]; then
    print_info "Downloading glibc"
    download_glibc
    touch $STAMPS_DOWNLOAD/$GLIBC_SRC
fi
exit

print_info "*******************************************"
print_info "Downloading sources for bootstrap completed"
print_info "*******************************************"

exit 0
