#!/bin/sh

# Copyright (C) 2019-2023 Svante Signell

# Written by Svante Signell  <svante.signell@gmail.com>

# This file is part of hurd-cross.

# Hurd-cross is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published
# by the Free Software Foundation; either version 3 or (at your
# option) any later version.

# Hurd-cross is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with hurd-cross.  If not, see <http://www.gnu.org/licenses/>.

. ./download-funcs.sh

echo ""
echo "File: download-compile.sh"

print_info "************************************"
print_info "Downloading source files for compile"
print_info "************************************"

download_gmp () {
   download $GMP_PKG $GMP_URL
   if [ -d "$GMP_SRC" ]; then
       return 0
   fi
   unpack jxf $GMP_PKG $GMP_SRC
}

download_mpfr () {
   download $MPFR_PKG $MPFR_URL
   if [ -d "$MPFR_SRC" ]; then
       return 0
   fi
   unpack Jxf $MPFR_PKG $MPFR_SRC
}

download_mpc () {
   download $MPC_PKG $MPC_URL
   if [ -d "$MPC_SRC" ]; then
       return 0
   fi
   unpack zxf $MPC_PKG $MPC_SRC
}

download_e2fsprogs () {
   download $E2FSPROGS_PKG $E2FSPROGS_URL
   if [ -d "$E2FSPROGS_SRC" ]; then
       return 0
   fi
   unpack zxf $E2FSPROGS_PKG $E2FSPROGS_SRC
   cd $E2FSPROGS_SRC
#   apply_patch $SCRIPT_DIR/patches/e2fsprogs/configure.ac.diff 1
#   apply_patch $SCRIPT_DIR/patches/e2fsprogs/lib_ext2fs_dirhash.c.diff 1
   cd ..
}

download_libgpg-error () {
   download $LIBGPG_ERROR_PKG $LIBGPG_ERROR_URL
   if [ -d "$LIBGPG_ERROR_SRC" ]; then
      return 0
   fi
   unpack jxf $LIBGPG_ERROR_PKG $LIBGPG_ERROR_SRC
   cd $LIBGPG_ERROR_SRC
#   apply_patch $SCRIPT_DIR/patches/libgpg-error/libgpg-error-gawk-5.0.diff 1
   cd ..
}

download_libgcrypt () {
   download $LIBGCRYPT_PKG $LIBGCRYPT_URL
   if [ -d "$LIBGCRYPT_SRC" ]; then
      return 0
   fi
   unpack jxf $LIBGCRYPT_PKG $LIBGCRYPT_SRC
}

download_libpciaccess () {
   download $LIBPCIACCESS_PKG $LIBPCIACCESS_URL
   if [ -d "$LIBPCIACCESS_SRC" ]; then
       return 0
   fi
   unpack zxf $LIBPCIACCESS_PKG $LIBPCIACCESS_SRC
}

download_pkg-config () {
   download $PKG_CONFIG_PKG $PKG_CONFIG_URL
   if [ -d "$PKG_CONFIG_SRC" ]; then
       return 0
   fi
   unpack zxf $PKG_CONFIG_PKG $PKG_CONFIG_SRC
}
   
download_util-linux () {
   download $UTIL_LINUX_PKG $UTIL_LINUX_URL
   if [ -d "$UTIL_LINUX_SRC" ]; then
       return 0
   fi
   unpack zxf $UTIL_LINUX_PKG $UTIL_LINUX_SRC
}
   
download_zlib () {
   download $ZLIB_PKG $ZLIB_URL
   if [ -d "$ZLIB_SRC" ]; then
      return 0
   fi
   unpack zxf $ZLIB_PKG $ZLIB_SRC
}

download_flex () {
   download $FLEX_PKG $FLEX_URL
   if [ -d "$FLEX_SRC" ]; then
      return 0
   fi
   unpack zxf $FLEX_PKG $FLEX_SRC
}

download_coreutils () {
    download $COREUTILS_PKG $COREUTILS_URL
    if [ -d "$COREUTILS_SRC" ]; then
	return 0
    fi
    unpack Jxf $COREUTILS_PKG $COREUTILS_SRC
}

download_bash() {
   download $BASH_PKG $BASH_URL
   if [ -d "$BASH_SRC" ]; then
      return 0
   fi
   unpack zxf $BASH_PKG $BASH_SRC
}

download_sed () {
    download $SED_PKG $SED_URL
    if [ -d "$SED_SRC" ]; then
	return 0
    fi
    unpack Jxf $SED_PKG $SED_SRC
}

download_ncurses () {
  download $NCURSES_PKG $NCURSES_URL
  if [ -d "$NCURSES_SRC" ]; then
    return 0
  fi
  unpack zxf $NCURSES_PKG $NCURSES_SRC
}

download_pam () {
    download $PAM_PKG $PAM_URL
    if [ -d "$PAM_SRC" ]; then
	return 0
    fi
    unpack Jxf $PAM_PKG $PAM_SRC
}

download_shadow () {
    download $SHADOW_PKG $SHADOW_URL
    if [ -d "$SHADOW_SRC" ]; then
	return 0
    fi
    unpack Jxf $SHADOW_PKG $SHADOW_SRC
#    Done in compile-patch.sh
#    cd $SHADOW_SRC
#    apply_patch $SCRIPT_DIR/patches/shadow/src_Makefile.am.diff 1
#    cd ..
}

download_grub () {
    download $GRUB_PKG $GRUB_URL
    if [ -d "$GRUB_SRC" ]; then
	return 0
    fi
    unpack zxf $GRUB_PKG $GRUB_SRC
}

download_nano () {
  download $NANO_PKG $NANO_URL
  if [ -d "$NANO_SRC" ]; then
    return 0
  fi
  unpack Jxf $NANO_PKG $NANO_SRC
}

download_less () {
  download $LESS_PKG $LESS_URL
  if [ -d "$LESS_SRC" ]; then
    return 0
  fi
  unpack zxf $LESS_PKG $LESS_SRC
}

download_grep () {
  download $GREP_PKG $GREP_URL
  if [ -d "$GREP_SRC" ]; then
    return 0
  fi
  unpack Jxf $GREP_PKG $GREP_SRC
}
download_vim () {
  download $VIM_PKG $VIM_URL
  if [ -d "vim$VIM_BASE_VERSION" ]; then
    return 0
  fi
  unpack jxf $VIM_PKG $VIM_SRC
}

cd $SRC

if [ ! -f $STAMPS_DOWNLOAD/$GMP_SRC ]; then
    print_info "Downloading gmp"
    download_gmp
    touch $STAMPS_DOWNLOAD/$GMP_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$MPFR_SRC ]; then
    print_info "Downloading mpfr"
    download_mpfr
    touch $STAMPS_DOWNLOAD/$MPFR_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$MPC_SRC ]; then
    print_info "Downloading mpc"
    download_mpc
    touch $STAMPS_DOWNLOAD/$MPC_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$E2FSPROGS_SRC ]; then
    print_info "Downloading e2fsprogs"
    download_e2fsprogs
    touch $STAMPS_DOWNLOAD/$E2FSPROGS_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$LIBGPG_ERROR_SRC ]; then
    print_info "Downloading libgpg-error"
    download_libgpg-error
    touch $STAMPS_DOWNLOAD/$LIBGPG_ERROR_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$LIBGCRYPT_SRC ]; then
    print_info "Downloading libgcrypt"
    download_libgcrypt
    touch $STAMPS_DOWNLOAD/$LIBGCRYPT_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$LIBPCIACCESS_SRC ]; then
    print_info "Downloading libpciaccess"
    download_libpciaccess
    touch $STAMPS_DOWNLOAD/$LIBPCIACCESS_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$PKG_CONFIG_SRC ]; then
    print_info "Downloading pkg-config"
    download_pkg-config
    touch $STAMPS_DOWNLOAD/$PKG_CONFIG_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$UTIL_LINUX_SRC ]; then
    print_info "Downloading util-linux"
    download_util-linux
    touch $STAMPS_DOWNLOAD/$UTIL_LINUX_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$ZLIB_SRC ]; then
    print_info "Downloading zlib"
    download_zlib
    touch $STAMPS_DOWNLOAD/$ZLIB_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$FLEX_SRC ]; then
    print_info "Downloading flex"
    download_flex
    touch $STAMPS_DOWNLOAD/$FLEX_SRC
fi
#exit
#if [ ! -f $DOWNLOAD/lwip-stamp ]; then
#    print_info "git clone lwip: Cannot be built, requires CMAKE"
#    download_lwip
#    touch $DOWNLOAD/lwip-stamp
#fi

if [ ! -f $STAMPS_DOWNLOAD/$COREUTILS_SRC ]; then
    print_info "Downloading coreutils"
    download_coreutils
    touch $STAMPS_DOWNLOAD/$COREUTILS_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$BASH_SRC ]; then
    print_info "Downloading bash"
    download_bash
    touch $STAMPS_DOWNLOAD/$BASH_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$SED_SRC ]; then
    print_info "Downloading sed"
    download_sed
    touch $STAMPS_DOWNLOAD/$SED_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$NCURSES_SRC ]; then
    print_info "Downloading ncurses"
    download_ncurses
    touch $STAMPS_DOWNLOAD/$NCURSES_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$PAM_SRC ]; then
    print_info "Downloading pam"
    download_pam
    touch $STAMPS_DOWNLOAD/$PAM_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$SHADOW_SRC ]; then
    print_info "Downloading shadow"
    download_shadow
    touch $STAMPS_DOWNLOAD/$SHADOW_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$GRUB_SRC ]; then
    print_info "Downloading grub"
    download_grub
    touch $STAMPS_DOWNLOAD/$GRUB_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$NANO_SRC ]; then
    print_info "Downloading nano"
    download_nano
    touch $STAMPS_DOWNLOAD/$NANO_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$LESS_SRC ]; then
    print_info "Downloading less"
    download_less
    touch $STAMPS_DOWNLOAD/$LESS_SRC
fi
#exit
if [ ! -f $STAMPS_DOWNLOAD/$GREP_SRC ]; then
    print_info "Downloading grep"
    download_grep
    touch $STAMPS_DOWNLOAD/$GREP_SRC
fi
#exit

#FIXME later
#download_vim

print_info "*********************************"
print_info "Downloading for compile completed"
print_info "*********************************"

exit 0
